Task: Multi-party chat in LIGHT
================

Multi-party async conversation between 3 role-playing characters.
For more information, please see our projects page: https://parl.ai/projects/multilight.

Tags: #All, #ChitChat, #LIGHT